@@ -15,6 +15,15 @@ API_URL = 'http://api.vk.com/api.php'
 SECURE_API_URL = 'https://api.vkontakte.ru/method/'
 DEFAULT_TIMEOUT = 1
 
+
+# See full list of VK API methods here:
+# http://vkontakte.ru/developers.php?o=-1&p=%D0%A0%D0%B0%D1%81%D1%88%D0%B8%D1%80%D0%B5%D0%BD%D0%BD%D1%8B%D0%B5_%D0%BC%D0%B5%D1%82%D0%BE%D0%B4%D1%8B_API&s=0
+COMPLEX_METHODS = ['secure', 'ads', 'messages', 'likes', 'friends',
+    'groups', 'photos', 'wall', 'newsfeed', 'notifications', 'audio',
+    'video', 'docs', 'places', 'storage', 'notes', 'pages',
+    'activity', 'offers', 'questions', 'subscriptions']
+
+
 class VKError(Exception):
     __slots__ = ["code", "description", "params"]
     def __init__(self, code, description, params):
@@ -31,7 +40,7 @@ def _to_utf8(s):
 def signature(api_secret, params):
     keys = sorted(params.keys())
     param_str = "".join(["%s=%s" % (str(key), _to_utf8(params[key])) for key in keys])
-    return md5(param_str+str(api_secret)).hexdigest()
+    return md5(param_str + str(api_secret)).hexdigest()
 
 def request(api_id, api_secret, method, timestamp=None, timeout=DEFAULT_TIMEOUT, **kwargs):
     msg = 'vkontakte.api.request is deprecated and will be removed. Please use `API` class.'
@@ -66,7 +75,7 @@ class API(object):
         '''
         Support for api.<method>.<methodName> syntax
         '''
-        if name in ['secure', 'ads']:
+        if name in COMPLEX_METHODS:
             api = API(api_id=self.api_id, api_secret=self.api_secret, token=self.token, **self.defaults)
             api.method_prefix = name + '.'
             return api
@@ -88,28 +97,29 @@ class API(object):
         if self.token:
             # http://vkontakte.ru/developers.php?oid=-1&p=Выполнение_запросов_к_API
             params = dict(
-                access_token = self.token
+                access_token=self.token,
             )
             params.update(kwargs)
+            params['timestamp'] = int(time.time())
             url = SECURE_API_URL + method
             secure = True
         else:
             # http://vkontakte.ru/developers.php?oid=-1&p=Взаимодействие_приложения_с_API
             params = dict(
-                api_id = str(self.api_id),
-                method = method,
-                format = 'JSON',
-                v = '3.0',
-                random = random.randint(0, 2**30),
+                api_id=str(self.api_id),
+                method=method,
+                format='JSON',
+                v='3.0',
+                random=random.randint(0, 2 ** 30),
             )
             params.update(kwargs)
+            params['timestamp'] = int(time.time())
             params['sig'] = self._signature(params)
             url = API_URL
             secure = False
-        params['timestamp'] = int(time.time())
         data = urllib.urlencode(params)
         headers = {"Accept": "application/json", "Content-Type": "application/x-www-form-urlencoded"}
 
         # urllib2 doesn't support timeouts for python 2.5 so
         # custom function is used for making http requests
-        return http.post(url, data, headers, timeout, secure=secure)
\ No newline at end of file
+        return http.post(url, data, headers, timeout, secure=secure)
